#!/usr/bin/tclsh
#
# Licensed under the OPENdj Software License.  See LICENSE file for details.
# Copyright 2001 DAX Interactive, LLC.
# 
proc replaceString { text find replace } {
    if { [string first "\$\$CHANNEL_" $find] == 0 } {
	set replace [string range $replace 1 [expr [string length $replace]-2]]
    }
    set foundpos 0
    set findlen [string length $find]
    set text2 ""
    while { $foundpos >= 0 } {
	set foundpos [string first $find $text]
	if { $foundpos < 0 } {
	    set text2 "$text2$text"
	    return $text2
	} else {
	    set text2 "$text2[string range $text 0 [expr $foundpos-1]]$replace"
	    set text [string range $text [expr $foundpos + $findlen] end]
	}
    }
    return $text2
}

# This script performs simple symbols substitutions
if { $argc < 1 } {
    puts stderr "Usage: replaceSyms.tcl <symbol-file>"
    puts stderr "Reads tempalte from stdin, substitutes symbols "
    puts stderr "defined in <symbol-file> and outputs formatted text"
    exit
}

# Read in all the symbols first
set symfile [open [lindex $argv 0]]  ; # open
set syms [split [read $symfile] \n]  ; # read
close $symfile                       ; # close

# Read in the entire input template
set templatedata [read stdin]

# Replace symbols in the file, one symbol at a time
for { set i 0 } { $i < [expr [llength $syms] - 1] } { incr i } {
    set symcouplet [split [lindex $syms $i] '=']
    set sname [lindex $symcouplet 0]
    set svalue [lindex $symcouplet 1]
    if { [string length sname] == 0 } continue
    set templatedata [replaceString $templatedata "\$\$$sname\$\$" $svalue]
}
puts $templatedata
